.. :changelog:

History
=======
0.4.2 (2016-03-13)
------------------
* Complete data elements added to default config.
* Added versioneer support for easier package versions

0.4.1 (2015-12-16)
------------------
* Additional data elements added to default config file.

0.4.0 (2015-10-05)
------------------
* Now supporting python 2.6 (for all those still using RHEL 6)
* Headers rows in mideu csv extracts don't work in 2.6

0.3.0 (2015-10-03)
------------------
* added sub commands for mideu
* mideu now supports IPM encoding conversion between ascii and ebcdic
* Now faster using list comps instead of slow loops

0.2.0 (2015-08-28)
------------------
* Support for config override for mideu - see usage doco
* Progress bar while using mideu.. it takes a while
* Now supports python 3.4, 3.5 and 2.7. Upgrade if you are using 2.6
* New usage documentation

0.1.0 (2015-08-20)
------------------
* First release.
